==> qxmledit-0.8.8-1-src.tgz: qxmledit-0.8.8-1/src/xsdeditor/XsdException.cpp <==
/**************************************************************************
 *  This file is part of QXmlEdit                                         *
 *  Copyright (C) 2011 by Luca Bellonda and individual contributors       *
 *    as indicated in the AUTHORS file                                    *
 *  lbellonda _at_ gmail.com                                              *
 *                                                                        *
 * This library is free software; you can redistribute it and/or          *
 * modify it under the terms of the GNU Library General Public            *
 * License as published by the Free Software Foundation; either           *
 * version 2 of the License, or (at your option) any later version.       *
 *                                                                        *
 * This library is distributed in the hope that it will be useful,        *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
 * Library General Public License for more details.                       *
 *                                                                        *
 * You should have received a copy of the GNU Library General Public      *
 * License along with this library; if not, write to the                  *
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,       *
 * Boston, MA  02110-1301  USA                                            *
 **************************************************************************/
#include "xsdeditor/xschema.h"
#include "utils.h"

XsdException::XsdException(const QString &theCause) : _cause(theCause)
{
    Utils::error(QString("TODO: exception thrown, cause:%1 ").arg(theCause));
}

XsdException::XsdException()
{
}

const char* XsdException::what() const throw()
{
    return _cause.toLatin1().data();
}

QString XsdException::cause() const throw()
{
    return _cause;
}

XsdException::~XsdException() throw()
{
}

void XsdError(const QString &message)
{
    throw new XsdException(message);
}

==> qxmledit-0.9.9.2-src.tgz: qxmledit-0.9.9.2/src/xsdeditor/XsdException.cpp <==
/**************************************************************************
 *  This file is part of QXmlEdit                                         *
 *  Copyright (C) 2011 by Luca Bellonda and individual contributors       *
 *    as indicated in the AUTHORS file                                    *
 *  lbellonda _at_ gmail.com                                              *
 *                                                                        *
 * This library is free software; you can redistribute it and/or          *
 * modify it under the terms of the GNU Library General Public            *
 * License as published by the Free Software Foundation; either           *
 * version 2 of the License, or (at your option) any later version.       *
 *                                                                        *
 * This library is distributed in the hope that it will be useful,        *
 * but WITHOUT ANY WARRANTY; without even the implied warranty of         *
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU      *
 * Library General Public License for more details.                       *
 *                                                                        *
 * You should have received a copy of the GNU Library General Public      *
 * License along with this library; if not, write to the                  *
 * Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,       *
 * Boston, MA  02110-1301  USA                                            *
 **************************************************************************/
#include "xsdeditor/xschema.h"
#include "utils.h"

XsdException::XsdException(const QString &theCause) : _cause(theCause)
{
    Utils::error(QString("Exception thrown, cause:%1 ").arg(theCause));
}

const char* XsdException::what() const throw()
{
    return _cause.toLatin1().data();
}

QString XsdException::cause() const throw()
{
    return _cause;
}

XsdException::~XsdException() throw()
{
}

void XsdError(const QString &message)
{
    throw new XsdException(message);
}
